diff avformat.h @ 5210:36d130853c9b libavformat

Improve amortized worst case speed of the muxers packet interleaving code from O(packets_in_the_file) to O(num_of_streams).
author michael
date Wed, 16 Sep 2009 20:04:04 +0000
parents cd884511ec8b
children 35aaa4f2ad8d
line wrap: on
line diff
--- a/avformat.h	Wed Sep 16 18:06:29 2009 +0000
+++ b/avformat.h	Wed Sep 16 20:04:04 2009 +0000
@@ -452,10 +452,10 @@
     int probe_packets;
 
     /**
      * Number of packets in packet_buffer for this stream when muxing.
      * used internally, NOT PART OF PUBLIC API, dont read or write from outside of libav*
      */
-    int num_in_packet_buffer;
+    struct AVPacketList *last_in_packet_buffer;
 } AVStream;
 
 #define AV_PROGRAM_RUNNING 1
@@ -452,10 +452,10 @@
 
     /**
-     * Number of packets in packet_buffer for this stream when muxing.
+     * last packet in packet_buffer for this stream when muxing.
      * used internally, NOT PART OF PUBLIC API, dont read or write from outside of libav*
      */